@@ -414,10 +414,10 @@ class Model:
             for style in self.styles:
                 if style.row > sizetable[0]:
                     style.row = style.row + sizetable[1]
-            for row_height in self.rows_height:
+            for row_height in self.__rows_height:
                 if row_height.row > sizetable[0]:
                     row_height.row = row_height.row + sizetable[1]
-        rows_height = self.rows_height
+        rows_height = self.__rows_height
         for sizetable in sizetables:
             for row_height in rows_height:
                  if row_height.row == sizetable[0]:
@@ -433,7 +433,7 @@ class Model:
             style.rename()
         return None
 
-    def import_data(self, data):
+    def data(self, data):
         """
         Documentation
         """
@@ -456,7 +456,7 @@ class Model:
                         self.__variables.append(Variable(variable.name+str(n),variable.row+n,variable.column,table[variable.name]))
         return None
 
-    def past_in_worksheet(self,worksheet):
+    def upload(self,worksheet):
         """
         Documentation
         """
